@@ -1,9 +1,9 @@
 /*
  * src/properties.c - control panel applet for gnome-volume-manager
  *
- * Robert Love <rml@ximian.com>
+ * Robert Love <rml@novell.com>
  *
- * (C) Copyright 2004 Novell, Inc.
+ * (C) Copyright 2005 Novell, Inc.
  *
  * Licensed under the GNU GPL v2.  See COPYING.
  */
@@ -329,25 +329,45 @@ check_if_hal_is_running (void)
 	LibHalContext *ctx;
 	char **devices;
 	int nr;
+	DBusError error;
+	DBusConnection *conn;
 
-	ctx = hal_initialize (NULL, FALSE);
+	ctx = libhal_ctx_new ();
 	if (!ctx)
 		return FALSE;
 
+	dbus_error_init (&error);
+
+	conn = dbus_bus_get (DBUS_BUS_SYSTEM, &error);
+	if (dbus_error_is_set (&error)) {
+		dbus_error_free (&error);
+		return FALSE;
+	}
+
+	libhal_ctx_set_dbus_connection (ctx, conn);
+
+	if(!libhal_ctx_init (ctx, &error)) {
+		dbus_error_free (&error);
+		return FALSE;
+	}
+
 	/*
 	 * Do something to ping the HAL daemon - the above functions will
 	 * succeed even if hald is not running, so long as DBUS is.  But we
 	 * want to exit silently if hald is not running, to behave on
 	 * pre-2.6 systems.
 	 */
-	devices = hal_get_all_devices (ctx, &nr);
+	devices = libhal_get_all_devices (ctx, &nr, &error);
 	if (!devices) {
-		hal_shutdown (ctx);
+		libhal_ctx_shutdown (ctx, NULL);
+		libhal_ctx_free (ctx);
+		dbus_error_free (&error);
 		return FALSE;
 	}
-	hal_free_string_array (devices);
+	libhal_free_string_array (devices);
 
-	hal_shutdown (ctx);
+	libhal_ctx_shutdown (ctx, NULL);
+	libhal_ctx_free (ctx);
 	return TRUE;
 }
 
@@ -373,7 +393,7 @@ init_capplet (void)
 						 0, GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
 						 _("Volume management not supported"));
-		gtk_message_dialog_format_secondary_text (GTK_DIALOG (dialog),
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("The \"hald\" service is required but not currently "
 							    "running. Enable the service and rerun this applet, "
 							    "or contact your system administrator."));
@@ -399,7 +419,7 @@ init_capplet (void)
 						 GTK_BUTTONS_OK,
 						 _("Could not load the main "
 						   "interface"));
-		gtk_message_dialog_format_secondary_text (GTK_DIALOG (dialog),
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 				 _("Please make sure that the "
 				   "volume manager is properly "
 				   "installed"));
